==> nextcloud-23.0.9.tgz: nextcloud/apps/viewer/l10n/hr.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Preglednik",
    "Simple file viewer with slideshow for media" : "Jednostavan preglednik datoteka s mogućnošću prezentacije medijski datoteka",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Pokažite svoje najnovije fotografije i videozapise s odmora kao u filmovima, predstavite ulomke najnovijeg romana izravno iz svog nextclouda, odaberite najbolji GIF iz kolekcije zahvaljujući izravnom pregledu omiljenih datoteka i još mnogo toga!",
    "Your browser does not support audio." : "Vaš preglednik ne podržava zvuk.",
    "Error loading {name}" : "Pogreška pri učitavanju {name}",
    "Unsaved changes" : "Nespremljene promjene",
    "Your browser does not support videos." : "Vaš preglednik ne podržava videozapise.",
    "Edit" : "Uredi",
    "Open sidebar" : "Otvori bočnu traku",
    "Download" : "Preuzmi",
    "Delete" : "Izbriši",
    "There is no plugin available to display this file type" : "Nema dostupnog dodatka za prikazivanje ove vrste datoteke",
    "View" : "Pregledaj",
    "Name" : "Naziv",
    "Save" : "Spremi",
    "Back" : "Natrag",
    "Loading …" : "Učitavanje…",
    "Reset" : "Resetiraj",
    "Cancel" : "Odustani",
    "Continue" : "Nastavi",
    "Undo" : "Poništi",
    "Redo" : "Ponovno",
    "Zoom in" : "Uvećaj",
    "Original" : "Izvornik",
    "Custom" : "Prilagođeno",
    "Value" : "Vrijednost",
    "Image" : "Slika",
    "Text" : "Tekst",
    "Size" : "Veličina",
    "Position" : "Položaj",
    "Extension" : "Proširenje",
    "Name is required." : "Ime je obavezno.",
    "Quality" : "Kvaliteta"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> nextcloud-24.0.11.tgz: nextcloud/apps/viewer/l10n/hr.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Preglednik",
    "Simple file viewer with slideshow for media" : "Jednostavan preglednik datoteka s mogućnošću prezentacije medijski datoteka",
    "Your browser does not support audio." : "Vaš preglednik ne podržava zvuk.",
    "Error loading {name}" : "Pogreška pri učitavanju {name}",
    "Image saved" : "Slika je spremljena",
    "Unsaved changes" : "Nespremljene promjene",
    "Your browser does not support videos." : "Vaš preglednik ne podržava videozapise.",
    "Edit" : "Uredi",
    "Open sidebar" : "Otvori bočnu traku",
    "Download" : "Preuzmi",
    "Delete" : "Izbriši",
    "There is no plugin available to display this file type" : "Nema dostupnog dodatka za prikazivanje ove vrste datoteke",
    "View" : "Pregledaj",
    "Name" : "Naziv",
    "Save" : "Spremi",
    "Back" : "Natrag",
    "Loading …" : "Učitavanje…",
    "Reset" : "Resetiraj",
    "Cancel" : "Odustani",
    "Continue" : "Nastavi",
    "Undo" : "Poništi",
    "Redo" : "Ponovno",
    "Zoom in" : "Uvećaj",
    "Original" : "Izvornik",
    "Custom" : "Prilagođeno",
    "Value" : "Vrijednost",
    "Image" : "Slika",
    "Text" : "Tekst",
    "Size" : "Veličina",
    "Position" : "Položaj",
    "Extension" : "Proširenje",
    "Name is required." : "Ime je obavezno.",
    "Quality" : "Kvaliteta",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Pokažite svoje najnovije fotografije i videozapise s odmora kao u filmovima, predstavite ulomke najnovijeg romana izravno iz svog nextclouda, odaberite najbolji GIF iz kolekcije zahvaljujući izravnom pregledu omiljenih datoteka i još mnogo toga!"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
